==> android-4.0.1.2-sources.jar: android/renderscript/RSTextureView.java <==
package android.renderscript;
public class RSTextureView
  extends android.view.TextureView
  implements android.view.TextureView.SurfaceTextureListener
{
public  RSTextureView(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  RSTextureView(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  void onSurfaceTextureAvailable(android.graphics.SurfaceTexture surface, int width, int height) { throw new RuntimeException("Stub!"); }
public  void onSurfaceTextureSizeChanged(android.graphics.SurfaceTexture surface, int width, int height) { throw new RuntimeException("Stub!"); }
public  boolean onSurfaceTextureDestroyed(android.graphics.SurfaceTexture surface) { throw new RuntimeException("Stub!"); }
public  void onSurfaceTextureUpdated(android.graphics.SurfaceTexture surface) { throw new RuntimeException("Stub!"); }
public  void pause() { throw new RuntimeException("Stub!"); }
public  void resume() { throw new RuntimeException("Stub!"); }
public  android.renderscript.RenderScriptGL createRenderScriptGL(android.renderscript.RenderScriptGL.SurfaceConfig sc) { throw new RuntimeException("Stub!"); }
public  void destroyRenderScriptGL() { throw new RuntimeException("Stub!"); }
public  void setRenderScriptGL(android.renderscript.RenderScriptGL rs) { throw new RuntimeException("Stub!"); }
public  android.renderscript.RenderScriptGL getRenderScriptGL() { throw new RuntimeException("Stub!"); }
}

==> android-4.1.1.4-sources.jar: android/renderscript/RSTextureView.java <==
package android.renderscript;
@Deprecated
public class RSTextureView
  extends android.view.TextureView
  implements android.view.TextureView.SurfaceTextureListener
{
@Deprecated
public  RSTextureView(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
@Deprecated
public  RSTextureView(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
@Deprecated
public  void onSurfaceTextureAvailable(android.graphics.SurfaceTexture surface, int width, int height) { throw new RuntimeException("Stub!"); }
@Deprecated
public  void onSurfaceTextureSizeChanged(android.graphics.SurfaceTexture surface, int width, int height) { throw new RuntimeException("Stub!"); }
@Deprecated
public  boolean onSurfaceTextureDestroyed(android.graphics.SurfaceTexture surface) { throw new RuntimeException("Stub!"); }
@Deprecated
public  void onSurfaceTextureUpdated(android.graphics.SurfaceTexture surface) { throw new RuntimeException("Stub!"); }
@Deprecated
public  void pause() { throw new RuntimeException("Stub!"); }
@Deprecated
public  void resume() { throw new RuntimeException("Stub!"); }
@Deprecated
public  android.renderscript.RenderScriptGL createRenderScriptGL(android.renderscript.RenderScriptGL.SurfaceConfig sc) { throw new RuntimeException("Stub!"); }
@Deprecated
public  void destroyRenderScriptGL() { throw new RuntimeException("Stub!"); }
@Deprecated
public  void setRenderScriptGL(android.renderscript.RenderScriptGL rs) { throw new RuntimeException("Stub!"); }
@Deprecated
public  android.renderscript.RenderScriptGL getRenderScriptGL() { throw new RuntimeException("Stub!"); }
}
